{
  description = "NixOS/Darwin system configuration";

  inputs = {
    nixpkgs.url = "nixpkgs/nixos-22.11";
    home-manager = {
      url = "github:nix-community/home-manager/release-22.11";
      inputs.nixpkgs.follows = "nixpkgs";
    };
  };

  outputs = inputs @ { nixpkgs, home-manager, ... }:
    let
      inherit (lib) attrValues;
      inherit (lib.my) mapModules mapModulesRec;

      mkPkgs = pkgs:
        import pkgs {
          config.allowUnfree = true;
        };
      pkgs = mkPkgs nixpkgs;

      lib = nixpkgs.lib.extend (self: super: {
        my = import ./lib {
          inherit pkgs inputs;
          lib = self;
        };
      });
    in {
      lib = lib.my;

      nixosModules = mapModulesRec ./modules import;

      nixosConfigurations = {
        atlas = nixpkgs.lib.nixosSystem {
          system = "x86_64-linux";
          modules = [
            inputs.home-manager.nixosModules.home-manager
            (import ./modules)
            ./hosts/atlas
          ];
          specialArgs = { inherit lib inputs; };
        };
        eos = nixpkgs.lib.nixosSystem {
          system = "x86_64-linux";
          modules = [
            inputs.home-manager.nixosModules.home-manager
            (import ./modules)
            ./hosts/eos
          ];
          specialArgs = { inherit lib inputs; };
        };
        helios = nixpkgs.lib.nixosSystem {
          system = "x86_64-linux";
          modules = [
            inputs.home-manager.nixosModules.home-manager
            (import ./modules)
            ./hosts/helios
          ];
          specialArgs = { inherit lib inputs; };
        };
        odyssey = nixpkgs.lib.nixosSystem {
          system = "x86_64-linux";
          modules = [
            inputs.home-manager.nixosModules.home-manager
            (import ./modules)
            ./hosts/odyssey
          ];
          specialArgs = { inherit lib inputs; };
        };
      };
  };
}
